combine_footers: Combines footer data from a dp object list into a single data
frame
Description
Given a dp object list, this function will extract all footers
(the additional measurement data) from all dp objects in a given
list and combine them in a single data frame. Will not work if
trying to combine footer from newer and older format of data.
Usage
combine_footers(dp.list)
Arguments
dp.list
A list of dp objects, either from loading several
files using dpload or combined manually. Note: the list should
include only dp objects!
Value
A data frame, combining all footer data from dp.list